class Game extends Phaser.Scene {
    constructor(game) {
        super('Game');
        this.game = game;
    }

    preload() {
        this.gm = new GamingBoard();
        this.game.scene.add('GamingBoard', this.gm);
    }

    create() {
        //this.add.image(0,0,'background').alpha = 0.1;

        let btn = this.add.sprite(WIDTH_WINDOW / 1.5, (HEIGHT_WINDOW / 3) * 2, 'btn_play').setOrigin(0.5, 0.5).setInteractive();
        //btn.setFrame(0);
        btn.on('pointerout', () => btn.setFrame(0));
        btn.on('pointerover', () => btn.setFrame(1));
        btn.on('pointerdown', () => this.clickPlay(btn));
        this.scene.launch('GamingBoard');
        this.scene.pause('GamingBoard');


        this.tree = new RectangleNode(WIDTH_WINDOW / 1.5, 100, this, 'waria');
        this.tree.addRect(new RectangleNode(WIDTH_WINDOW / 1.2, 400, this, 'move', true))
        this.tree.addRect(new RectangleNode(WIDTH_WINDOW / 1.5, 400, this, 'attack'));


        let robot = new Robot(WIDTH_MAP * 0.1, WIDTH_MAP * 0.1, WIDTH_MAP * 0.9, WIDTH_MAP * 0.9, 0x6666ff, this.gm);
        let condition = new RectangleNode(WIDTH_WINDOW / 1.7, 400, this, 'condition', robot, true, false, 0.5, 0);
        condition.addRect(new RectangleNode(WIDTH_WINDOW / 1.2, 600, this, 'move', false));
        condition.addRect(new RectangleNode(WIDTH_WINDOW / 1.5, 600, this, 'attack'))
        this.tree.addRect(condition);

        this.gm.addRobot(robot);
        this.gm.addRobot(new Robot(WIDTH_MAP * 0.1, WIDTH_MAP * 0.1, WIDTH_MAP * 0.2, WIDTH_MAP * 0.1, 0xff33cc, this.gm));
        this.gm.addRobot(new Robot(WIDTH_MAP * 0.1, WIDTH_MAP * 0.1, WIDTH_MAP * 0.1, WIDTH_MAP * 0.9, 0xffffff, this.gm));

        this.input.on('drag', this.doDrag);
    }

    update(time, delta) {
        super.update(time, delta);
        this.tree.updateLine();
    }

    doDrag(pointer, target, dragX, dragY) {
        target.setX(dragX);
        target.setY(dragY);
    }

    clickPlay(btn) {
        btn.setFrame(2);
        if (this.scene.isPaused('GamingBoard'))
            this.resume();
        else
            this.scene.pause('GamingBoard');
    }

    resume() {
        const sortDesc = (a, b) => a.getX() - b.getX();
        this.tree.lRect.sort(sortDesc);
        this.tree.lRect.forEach(function (element) {
            if (element.lRect !== undefined) {
                element.lRect.sort(sortDesc);
            }
        })
        this.gm.modifyNodes(this.tree.getNodes());
        this.scene.resume('GamingBoard');
    }
}